==> kazehakase-0.2.1.tar.gz: kazehakase-0.2.1/src/actions/kz-zoom-action.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2004 Hiroyuki Ikezoe
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef KZ_ZOOM_ACTION_H
#define KZ_ZOOM_ACTION_H

#include <gtk/gtk.h>

#include "kz-window.h"

#define KZ_TYPE_ZOOM_ACTION            (kz_zoom_action_get_type())
#define KZ_ZOOM_ACTION(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), KZ_TYPE_ZOOM_ACTION, KzZoomAction))
#define KZ_ZOOM_ACTION_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass), KZ_TYPE_ZOOM_ACTION, KzZoomActionClass))
#define KZ_IS_ZOOM_ACTION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), KZ_TYPE_ZOOM_ACTION))
#define KZ_IS_ZOOM_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((obj), KZ_TYPE_ZOOM_ACTION))
#define KZ_ZOOM_ACTION_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), KZ_TYPE_ZOOM_ACTION, KzZoomActionClass))

typedef struct _KzZoomAction        KzZoomAction;
typedef struct _KzZoomActionPrivate KzZoomActionPrivate;
typedef struct _KzZoomActionClass   KzZoomActionClass;

struct _KzZoomAction
{
	GtkAction   parent;
  	KzZoomActionPrivate *priv;
};

struct _KzZoomActionClass
{
	GtkActionClass parent_class;
};

GType         kz_zoom_action_get_type  (void);
KzZoomAction *kz_zoom_action_new       (KzWindow   *kz);

void	      kz_zoom_action_set_ratio (KzZoomAction *action,
					gint ratio);
gint	      kz_zoom_action_get_ratio (KzZoomAction *action);

#endif /* KZ_ZOOM_ACTION_H */

==> kazehakase-0.4.3.tar.gz: kazehakase-0.4.3/src/actions/kz-zoom-action.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2004 Hiroyuki Ikezoe
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef KZ_ZOOM_ACTION_H
#define KZ_ZOOM_ACTION_H

#include <gtk/gtk.h>

#include "kz-window.h"

#define KZ_TYPE_ZOOM_ACTION            (kz_zoom_action_get_type())
#define KZ_ZOOM_ACTION(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), KZ_TYPE_ZOOM_ACTION, KzZoomAction))
#define KZ_ZOOM_ACTION_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass), KZ_TYPE_ZOOM_ACTION, KzZoomActionClass))
#define KZ_IS_ZOOM_ACTION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), KZ_TYPE_ZOOM_ACTION))
#define KZ_IS_ZOOM_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((obj), KZ_TYPE_ZOOM_ACTION))
#define KZ_ZOOM_ACTION_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), KZ_TYPE_ZOOM_ACTION, KzZoomActionClass))

typedef struct _KzZoomAction        KzZoomAction;
typedef struct _KzZoomActionClass   KzZoomActionClass;

struct _KzZoomAction
{
	GtkAction   parent;
};

struct _KzZoomActionClass
{
	GtkActionClass parent_class;
};

GType         kz_zoom_action_get_type  (void) G_GNUC_CONST;
KzZoomAction *kz_zoom_action_new       (KzWindow   *kz);

void	      kz_zoom_action_set_ratio (KzZoomAction *action,
					gint ratio);
gint	      kz_zoom_action_get_ratio (KzZoomAction *action);

#endif /* KZ_ZOOM_ACTION_H */
